// -*-Mode: C++;-*- 
/*
 * $Id: createtable.h,v 2.11 2001/04/08 14:00:03 ral Exp $
 */
#ifndef CCreateTable_included
#define CCreateTable_included

#include "modifytable.h"
#include <qlined.h>
#include <qlist.h>
#include "tabledescr.h"
#include "stringlist.h"

class CMySql;

class CCreateTable : public CModifyTable
{
    Q_OBJECT

public:

    CCreateTable(smart_pointer<CMySql>& _sql_server,QWidget* parent = NULL,const char* name = NULL);
    virtual ~CCreateTable();

protected slots:
    virtual void TableTextChanged(const QString&text);
    virtual void TableTextActivate();
    virtual void SetDBString(const QString&);
    virtual void AddColumn();
    virtual void Delete_Column();
    virtual void CreateTable();

protected:
    QLineEdit*TableNameEdit;
};
#endif // CCreateTable_included
